==> pexpect_serial_terminal-0.5.0a1-py3-none-any.whl: pexpect_serial_terminal/__main__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys, os, getopt
import serial
from .serial_terminal import SerialTerminal
from ._version import __version__ as version

help_string = 'Usage: %s [option] <parameter>\nThe option and option\'s parameter list below:\n' \
    'Ex:\n' \
    '\t%s -p COM3 -b 115200\n\n' \
    '-p | --port\n' \
    '\t[ default value: None ]\n' \
    '\tSerial port name.\n' \
    \
    '-b | --baud-rate\n' \
    '\t[ default value: 115200 ]\n' \
    '\tBaud rate.\n' \
    \
    '-w | --data-bits\n' \
    '\t[ default value: 8 ]\n' \
    '\t< 8 | 7 >\n' \
    '\tData bits.\n' \
    \
    '-r | --parity\n' \
    '\t[ default value: None ]\n' \
    '\t< None | Even | Odd | Space | Mark >\n' \
    '\tParity.\n' \
    \
    '-s | --stop-bits\n' \
    '\t[ default value: 1 ]\n' \
    '\t< 1 | 2 | 1.5 >\n' \
    '\tStop bits.\n' \
    \
    '-x | --soft-flow-ctl\n' \
    '\t[ default value: off ]\n' \
    '\t< on | off >\n' \
    '\tSoftware flow control switch.\n' \
    \
    '-f | --hard-flow-ctl\n' \
    '\t[ default value: off ]\n' \
    '\t< on | off >\n' \
    '\tHardware flow control switch.\n' \
    \
    '\nversion %s'

def usage():
    print(help_string % (sys.argv[0], sys.argv[0], version))

valid_parity = {
    'NONE'  : serial.PARITY_NONE,
    'EVEN'  : serial.PARITY_EVEN,
    'ODD'   : serial.PARITY_ODD,
    'MARK'  : serial.PARITY_MARK,
    'SPACE' : serial.PARITY_SPACE
}

valid_stop_bits = {
    '1'     : serial.STOPBITS_ONE,
    '1.5'   : serial.STOPBITS_ONE_POINT_FIVE,
    '2'     : serial.STOPBITS_TWO
}

def open_serial_port(config):
    if config['data-bits'] == 7:
        bytesize = serial.SEVENBITS
    else:
        bytesize = serial.EIGHTBITS
    parity = valid_parity[config['parity']]
    stopbits = valid_stop_bits[config['stop-bits']]
    if config['soft-flow-ctl']:
        xonxoff = True
    else:
        xonxoff = False
    if config['hard-flow-ctl']:
        rtscts = True
    else:
        rtscts = False
    return serial.Serial(port=config['port'], baudrate=config['baud-rate'],\
        bytesize=bytesize, parity=parity, stopbits=stopbits,\
        xonxoff=xonxoff, rtscts=rtscts, timeout=0)

def main(argv=None):
    if argv is None:
        argv = sys.argv[1:]
    config = {}
    try:
        opts, _ = getopt.getopt(argv, "hp:b:w:r:s:x:f:", \
            ["port=","baud-rate=","data-bits=","parity=","stop-bits=","soft-flow-ctl=","hard-flow-ctl="])
    except getopt.GetoptError:
        usage()
        sys.exit(2)

    config['port'] = None
    config['baud-rate'] = 115200
    config['data-bits'] = 8
    config['parity'] = 'NONE'
    config['stop-bits'] = '1'
    config['soft-flow-ctl'] = False
    config['hard-flow-ctl'] = False

    for opt, arg in opts:
        if opt == '-h':
            usage()
            sys.exit()
        elif opt in ("-p", "--port"):
            config['port'] = arg
        elif opt in ("-b", "--baud-rate"):
            config['baud-rate'] = int(arg)
        elif opt in ("-w", "--data-bits"):
            if int(arg) == 7:
                bits = 7
            else:
                bits = 8
            config['data-bits'] = bits
        elif opt in ("-r", "--parity"):
            parity = 'NONE'
            for item in valid_parity.keys():
                if item == arg.upper():
                    parity = arg.upper()
            config['parity'] = parity
        elif opt in ("-s", "--stop-bits"):
            stop_bits = '1'
            for item in valid_stop_bits.keys():
                if item == arg:
                    stop_bits = arg
            config['stop-bits'] = stop_bits
        elif opt in ("-x", "--soft-flow-ctl"):
            if arg.lower() == 'on':
                config['soft-flow-ctl'] = True
            else:
                config['soft-flow-ctl'] = False
        elif opt in ("-f", "--hard-flow-ctl"):
            if arg.lower() == 'on':
                config['hard-flow-ctl'] = True
            else:
                config['hard-flow-ctl'] = False

    for key in config:
        print('key:', key)
        print('value: %s' % str(config[key]))
    port = open_serial_port(config)
    if not port.is_open:
        print('serial port cannot open, please check your port settings!')
    terminal = SerialTerminal(port)
    terminal.start()

    while terminal.is_alive():
        char = sys.stdin.read(1)
        if char == '\x03': # Ctl-C
            break
        terminal.write(char)

    terminal.abort()
    port.close()

if __name__ == "__main__":
    main(sys.argv[1:])

==> pexpect_serial_terminal-0.5.2-py3-none-any.whl: pexpect_serial_terminal/__main__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import sys, os, getopt
import serial
from .serial_terminal import SerialTerminal
from ._version import __version__ as version

help_string = 'Usage: %s [option] <parameter>\nThe option and option\'s parameter list below:\n' \
    'Ex:\n' \
    '\t%s -p COM3 -b 115200\n\n' \
    '-l | --line-ending\n' \
    '\t[ default value: LF ]\n' \
    '\t< LF | CR | CRLF >\n' \
    '\tDevice line ending.\n' \
    \
    '-p | --port\n' \
    '\t[ default value: None ]\n' \
    '\tSerial port name.\n' \
    \
    '-b | --baud-rate\n' \
    '\t[ default value: 115200 ]\n' \
    '\tBaud rate.\n' \
    \
    '-w | --data-bits\n' \
    '\t[ default value: 8 ]\n' \
    '\t< 8 | 7 >\n' \
    '\tData bits.\n' \
    \
    '-r | --parity\n' \
    '\t[ default value: None ]\n' \
    '\t< None | Even | Odd | Space | Mark >\n' \
    '\tParity.\n' \
    \
    '-s | --stop-bits\n' \
    '\t[ default value: 1 ]\n' \
    '\t< 1 | 2 | 1.5 >\n' \
    '\tStop bits.\n' \
    \
    '-x | --soft-flow-ctl\n' \
    '\t[ default value: off ]\n' \
    '\t< on | off >\n' \
    '\tSoftware flow control switch.\n' \
    \
    '-f | --hard-flow-ctl\n' \
    '\t[ default value: off ]\n' \
    '\t< on | off >\n' \
    '\tHardware flow control switch.\n' \
    \
    '\nversion %s'

def usage():
    print(help_string % (sys.argv[0], sys.argv[0], version))

valid_parity = {
    'NONE'  : serial.PARITY_NONE,
    'EVEN'  : serial.PARITY_EVEN,
    'ODD'   : serial.PARITY_ODD,
    'MARK'  : serial.PARITY_MARK,
    'SPACE' : serial.PARITY_SPACE
}

valid_stop_bits = {
    '1'     : serial.STOPBITS_ONE,
    '1.5'   : serial.STOPBITS_ONE_POINT_FIVE,
    '2'     : serial.STOPBITS_TWO
}

valid_line_ending = ['CR', 'LF', 'CRLF']

def open_serial_port(config):
    if config['data-bits'] == 7:
        bytesize = serial.SEVENBITS
    else:
        bytesize = serial.EIGHTBITS
    parity = valid_parity[config['parity']]
    stopbits = valid_stop_bits[config['stop-bits']]
    if config['soft-flow-ctl']:
        xonxoff = True
    else:
        xonxoff = False
    if config['hard-flow-ctl']:
        rtscts = True
    else:
        rtscts = False
    return serial.Serial(port=config['port'], baudrate=config['baud-rate'],\
        bytesize=bytesize, parity=parity, stopbits=stopbits,\
        xonxoff=xonxoff, rtscts=rtscts, timeout=0)

def main(argv=None):
    if argv is None:
        argv = sys.argv[1:]
    config = {}
    try:
        opts, _ = getopt.getopt(argv, "hl:p:b:w:r:s:x:f:", \
            ["line-ending=","port=","baud-rate=","data-bits=","parity=","stop-bits=","soft-flow-ctl=","hard-flow-ctl="])
    except getopt.GetoptError:
        usage()
        sys.exit(1)

    config['line-ending'] = 'LF'
    config['port'] = None
    config['baud-rate'] = 115200
    config['data-bits'] = 8
    config['parity'] = 'NONE'
    config['stop-bits'] = '1'
    config['soft-flow-ctl'] = False
    config['hard-flow-ctl'] = False

    for opt, arg in opts:
        if opt == '-h':
            usage()
            sys.exit()
        elif opt in ("-l", "--line-ending"):
            line_ending = 'LF'
            for item in valid_line_ending:
                if item == arg.upper():
                    line_ending = arg.upper()
            config['line-ending'] = line_ending
        elif opt in ("-p", "--port"):
            config['port'] = arg
        elif opt in ("-b", "--baud-rate"):
            config['baud-rate'] = int(arg)
        elif opt in ("-w", "--data-bits"):
            if int(arg) == 7:
                bits = 7
            else:
                bits = 8
            config['data-bits'] = bits
        elif opt in ("-r", "--parity"):
            parity = 'NONE'
            for item in valid_parity.keys():
                if item == arg.upper():
                    parity = arg.upper()
            config['parity'] = parity
        elif opt in ("-s", "--stop-bits"):
            stop_bits = '1'
            for item in valid_stop_bits.keys():
                if item == arg:
                    stop_bits = arg
            config['stop-bits'] = stop_bits
        elif opt in ("-x", "--soft-flow-ctl"):
            if arg.lower() == 'on':
                config['soft-flow-ctl'] = True
            else:
                config['soft-flow-ctl'] = False
        elif opt in ("-f", "--hard-flow-ctl"):
            if arg.lower() == 'on':
                config['hard-flow-ctl'] = True
            else:
                config['hard-flow-ctl'] = False

    for key in config:
        print('key:', key)
        print('value: %s' % str(config[key]))
    port = open_serial_port(config)
    if not port.is_open:
        print('serial port cannot open, please check your port settings!')
        sys.exit(1)
    terminal = SerialTerminal(port)
    terminal.start()

    while terminal.is_alive():
        char = sys.stdin.read(1)
        if char == '\x03': # Ctl-C
            break
        if char == '\n':
            if config['line-ending'] == 'CR':
                terminal.write('\r')
            elif config['line-ending'] == 'LF':
                terminal.write('\n')
            elif config['line-ending'] == 'CRLF':
                terminal.write('\r\n')
        else:
            terminal.write(char)

    terminal.abort()
    port.close()

if __name__ == "__main__":
    main(sys.argv[1:])
